@@ -27,7 +27,7 @@
 __author__ = """\n""".join(['Abhik Banerjee', 'Vincent Gauthier'])
 
 import networkx as nx
-import random as RD
+import numpy.random as RD
 import numpy as N
 
 
@@ -53,7 +53,7 @@ class PGG_diffusion:
         self._nb_simulation_step = int(nb_simulation_step)
         self._nb_coop = collections.deque(maxlen=maxlen_queue)
         self._nb_def = collections.deque(maxlen=maxlen_queue)
-        self._infected_node = [RD.randint(0,self._nb_node-1) for x in xrange(self._nb_seeder)]
+        self._infected_node = [RD.randint(0,(self._nb_node-1)) for x in xrange(self._nb_seeder)]
         self._simulation_time = 0
         self.reset_send_update()
         for nd in self._G.nodes_iter():
@@ -130,7 +130,7 @@ class PGG_diffusion:
                 self.compute_payoffs(dealer)
             
             for infected in self._infected_node:
-                self.set_time_stamp(infected, self._simulation_time)
+                self.set_infected(infected, self._simulation_time)
             self.reset_send_update()
             self.diffusion_step()
             #for nd in self._G.nodes_iter():
@@ -204,7 +204,7 @@ class PGG_diffusion:
         for (key, val) in nodes_states.iteritems():
             self._G.node[key]['state'] = val
 
-    def set_time_stamp(self, node_id, time_stamp):
+    def set_infected(self, node_id, time_stamp):
         self._G.node[node_id]['state'] = 'I'
         self._G.node[node_id]['strategy'] = 'C'
         self._G.node[node_id]['time_stamp'] = time_stamp
